==> mountmanager_0.2.4.orig.tar.gz: mountmanager-0.2.4/sources/gui/widgetformount.h <==
//MountManager - the program for easy mounting of storage devices in Linux
//Copyright (C) 2007-2008 Tikhonov Sergey
//
//This file is part of MountManager Gui
//
//This program is free software; you can redistribute it and/or
//modify it under the terms of the GNU General Public License
//as published by the Free Software Foundation; either version 2
//of the License, or (at your option) any later version.
//
//This program is distributed in the hope that it will be useful,
//but WITHOUT ANY WARRANTY; without even the implied warranty of
//MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//GNU General Public License for more details.
//
//You should have received a copy of the GNU General Public License
//along with this program; if not, write to the Free Software
//Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
#ifndef WIDGETFORMOUNT_H
#define WIDGETFORMOUNT_H

#include <QtGui/QWidget>

class DiskCore;
class QLabel;
class QPushButton;
class DiskDevice;
class ChooseMountPointWidget;
class QLineEdit;

class WidgetForMount : public QWidget
{
	Q_OBJECT
	private slots:
		void mount();
	private:
		DiskCore *core;
		
		QLabel *headerLabel;

		QString currentBlockName;
		QString currentFileSystem;
		
		QLabel *mountPointLabel;
		ChooseMountPointWidget *mountPointLine;
		QLabel *optionsLabel;
		QLineEdit *optionsLine;

		QPushButton *hideButton;
		QPushButton *mountButton;
	public:
		WidgetForMount(DiskCore *core);
		~WidgetForMount();

		void setOptionsForMount(const QString& blockName,const QString& mountPoint,const QString& fileSystem,const QString& options);
};

#endif

==> mountmanager_0.2.6.orig.tar.gz: mountmanager-0.2.6/sources/gui/widgetformount.h <==
//MountManager - the program for easy mounting of storage devices in Linux
//Copyright (C) 2007-2008 Tikhonov Sergey
//
//This file is part of MountManager Gui
//
//This program is free software; you can redistribute it and/or
//modify it under the terms of the GNU General Public License
//as published by the Free Software Foundation; either version 2
//of the License, or (at your option) any later version.
//
//This program is distributed in the hope that it will be useful,
//but WITHOUT ANY WARRANTY; without even the implied warranty of
//MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//GNU General Public License for more details.
//
//You should have received a copy of the GNU General Public License
//along with this program; if not, write to the Free Software
//Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
#ifndef WIDGETFORMOUNT_H
#define WIDGETFORMOUNT_H

#include <QtGui/QWidget>

class DiskCore;
class QLabel;
class QPushButton;
class DiskDevice;
class ChooseMountPointWidget;
class QLineEdit;
class QToolButton;

class WidgetForMount : public QWidget
{
	Q_OBJECT
	private slots:
		void mount();
	private:
		DiskCore *core;
		
		QLabel *headerLabel;

		QString currentBlockName;
		QString currentFileSystem;
		
		QLabel *mountPointLabel;
		ChooseMountPointWidget *mountPointLine;
		QLabel *optionsLabel;
		QLineEdit *optionsLine;

		QToolButton *hideButton;
		QPushButton *mountButton;
	public:
		WidgetForMount(DiskCore *core);
		~WidgetForMount();

		void setOptionsForMount(const QString& blockName,const QString& mountPoint,const QString& fileSystem,const QString& options);
};

#endif
